import { SelectHTMLAttributes, FC, ChangeEventHandler } from 'react';
declare type BaseElement = HTMLSelectElement;
declare type BaseProps = SelectHTMLAttributes<BaseElement>;
declare type SelectVariant = 'filled' | 'transparent';
export interface SelectNativeProps extends BaseProps {
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    /**
     * Selects the different items in the dropdown menu. Must pre-exist in the dropdown menu and written in lowercase. Otherwise no value is selected.
     */
    readonly value: string;
    /**
     * An array of data used to create a dropdown menu.
     */
    readonly options: ReadonlyArray<{
        /**
         * The value used to define a selectable option.
         */
        readonly value: string;
        /**
         * String used to label the selected option.
         */
        readonly label: string;
        /**
         * If `true`, the selectable option will be disabled.
         */
        readonly disabled?: boolean;
    }>;
    /**
     * Executes a JavaScript when a user changes the selected option of an element.
     */
    readonly onChange: ChangeEventHandler<HTMLSelectElement>;
    /**
     * A name used to specify the particular element.
     */
    readonly name?: BaseProps['name'];
    /**
     * Set to true to force the user to select an option in a dropdown menu.
     */
    readonly required?: boolean;
    /**
     * Used to determine the width of a dropdown menu.
     */
    readonly width?: 'small' | 'medium' | 'large' | 'full';
    readonly variant?: SelectVariant;
    readonly placeholder?: string;
    /**
     * If `true`, SelectNative will be disabled.
     */
    readonly disabled?: boolean;
}
export declare const SelectNative: FC<SelectNativeProps>;
export {};
