"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TableHeader = void 0;

var _react = require("react");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _designparams = require("../designparams");

var _Checkbox = require("../Checkbox");

var _Table = require("./Table");

var _context = require("./context");

var _TableCells = require("./TableCells");

var _jsxRuntime = require("react/jsx-runtime");

var _excluded = ["children", "selected", "partial", "overlay", "menu"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/*
 * TableHeader
 *
 * Defines the group of special cells that make up the header
 * of the table. They allow to resize the columns.
 * You should use this to wrap the elements you pass to the
 * header property of the Table component.
 */
var TableHeaderGrid = _styledComponents.default.div.withConfig({
  displayName: "TableHeader__TableHeaderGrid",
  componentId: "sc-1wnct30-0"
})(["display:grid;grid-template-rows:", ";"], _designparams.componentSize.large);

var TableHeader = _ref => {
  var {
    children,
    selected = false,
    partial = false,
    overlay,
    menu
  } = _ref,
      props = _objectWithoutProperties(_ref, _excluded);

  var {
    onSelect,
    hasMenu,
    columnWidths,
    dispatchWidthsAction
  } = (0, _react.useContext)(_context.TableContext);
  var onChange = (0, _react.useCallback)(e => {
    if (onSelect !== undefined) {
      onSelect(e.target.checked);
    }
  }, [onSelect]);

  var numberOfColumns = _react.Children.count(children); // Set the column widths.
  // This will happen on first render (number of columns changes from 0).


  (0, _react.useEffect)(() => {
    if (columnWidths.length === 0) {
      dispatchWidthsAction({
        type: _context.WidthActionType.RESET_WIDTHS,
        numberOfColumns
      });
    }
  }, [dispatchWidthsAction, columnWidths.length, numberOfColumns]);
  var gridTemplateColumnsStyle = (0, _Table.useGridTemplateColumns)();
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(TableHeaderGrid, _objectSpread(_objectSpread({
    style: gridTemplateColumnsStyle
  }, props), {}, {
    children: [onSelect !== undefined ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_TableCells.TableHeaderCellCheckbox, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.Checkbox, {
        checked: selected,
        partial: partial,
        onChange: onChange
      })
    }) : null, overlay !== undefined ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_TableCells.OverlayContainer, {
      children: overlay
    }) : _react.Children.map(children, (cell, i) => {
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(_TableCells.TableHeaderCellContent, {
        "data-col": i,
        children: cell
      }, i);
    }), overlay === undefined && hasMenu ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_TableCells.TableHeaderCellMenu, {
      children: menu !== undefined ? menu : null
    }) : null]
  }));
};

exports.TableHeader = TableHeader;